@@ -25,18 +25,28 @@ __all__ = [
     "EventSchema",
     "QueueSchema",
     "PrincipalSchema",
-    "RoleSchema",
+    "LegacyRoleSchema",
     "RefreshTokenSchema",
     "JobSchema",
+    "JobExportSchema",
+    "JobExportInputSchema",
+    "JobExportListSchema",
     "DateTriggerSchema",
     "IntervalTriggerSchema",
     "CronTriggerSchema",
     "FileTriggerSchema",
     "GardenSchema",
     "OperationSchema",
+    "UserSchema",
+    "UserCreateSchema",
+    "UserListSchema",
+    "RoleSchema",
+    "RoleAssignmentSchema",
 ]
 
 # This will be updated after all the schema classes are defined
+from brewtils.models import Job
+
 model_schema_map = {}
 
 
@@ -124,7 +134,7 @@ class DateTime(fields.DateTime):
 class BaseSchema(Schema):
     class Meta:
         version_nums = marshmallow.__version__.split(".")
-        if int(version_nums[0]) <= 2 and int(version_nums[1]) < 17:
+        if int(version_nums[0]) <= 2 and int(version_nums[1]) < 17:  # pragma: no cover
             json_module = simplejson
         else:
             render_module = simplejson
@@ -379,13 +389,13 @@ class QueueSchema(BaseSchema):
 class PrincipalSchema(BaseSchema):
     id = fields.Str(allow_none=True)
     username = fields.Str(allow_none=True)
-    roles = fields.Nested("RoleSchema", many=True, allow_none=True)
+    roles = fields.Nested("LegacyRoleSchema", many=True, allow_none=True)
     permissions = fields.List(fields.Str(), allow_none=True)
     preferences = fields.Dict(allow_none=True)
     metadata = fields.Dict(allow_none=True)
 
 
-class RoleSchema(BaseSchema):
+class LegacyRoleSchema(BaseSchema):
     id = fields.Str(allow_none=True)
     name = fields.Str(allow_none=True)
     description = fields.Str(allow_none=True)
@@ -471,6 +481,27 @@ class JobSchema(BaseSchema):
     timeout = fields.Int(allow_none=True)
 
 
+class JobExportInputSchema(BaseSchema):
+    ids = fields.List(fields.String(allow_none=True))
+
+
+class JobExportSchema(JobSchema):
+    def __init__(self, *args, **kwargs):
+        # exclude fields from a Job that we don't want when we later go to import
+        # the Job definition
+        self.opts.exclude += ("id", "next_run_time", "success_count", "error_count")
+        super(JobExportSchema, self).__init__(*args, **kwargs)
+
+    @post_load
+    def make_object(self, data):
+        # this is necessary because everything here revolves around brewtils models
+        return Job(**data)
+
+
+class JobExportListSchema(BaseSchema):
+    jobs = fields.List(fields.Nested(JobExportSchema, allow_none=True))
+
+
 class OperationSchema(BaseSchema):
     model_type = fields.Str(allow_none=True)
     model = ModelField(allow_none=True, type_field="model_type")
@@ -500,6 +531,33 @@ class ResolvableSchema(BaseSchema):
     details = fields.Dict(allow_none=True)
 
 
+class RoleSchema(BaseSchema):
+    id = fields.Str()
+    name = fields.Str()
+    description = fields.Str()
+    permissions = fields.List(fields.Str())
+
+
+class RoleAssignmentSchema(BaseSchema):
+    domain = fields.Str()
+    role = fields.Nested(RoleSchema())
+
+
+class UserSchema(BaseSchema):
+    id = fields.Str()
+    username = fields.Str()
+    role_assignments = fields.List(fields.Nested(RoleAssignmentSchema()))
+
+
+class UserCreateSchema(BaseSchema):
+    username = fields.Str(required=True)
+    password = fields.Str(required=True, load_only=True)
+
+
+class UserListSchema(BaseSchema):
+    users = fields.List(fields.Nested(UserSchema()))
+
+
 model_schema_map.update(
     {
         "Choices": ChoicesSchema,
@@ -512,6 +570,7 @@ model_schema_map.update(
         "Instance": InstanceSchema,
         "IntervalTrigger": IntervalTriggerSchema,
         "Job": JobSchema,
+        "JobExport": JobExportSchema,
         "LoggingConfig": LoggingConfigSchema,
         "Queue": QueueSchema,
         "Parameter": ParameterSchema,
@@ -524,7 +583,7 @@ model_schema_map.update(
         "FileChunk": FileChunkSchema,
         "FileStatus": FileStatusSchema,
         "RequestTemplate": RequestTemplateSchema,
-        "Role": RoleSchema,
+        "LegacyRole": LegacyRoleSchema,
         "System": SystemSchema,
         "Operation": OperationSchema,
         "Runner": RunnerSchema,
